lilypondfiletools.LilyPondVersionToken
======================================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.version
      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__eq__
      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__format__
      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__ne__
      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.version
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken.__repr__
   :noindex:
